<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Cdn\ICdnService;

class CdnController extends BaseController
{
    private $time;
    private $cdnService;

    public function __construct(ICdnService $cdnService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->cdnService = $cdnService;
    }

    /**
     * 新增cdn
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCdnAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'originSite' => 'required|string',
            'useDomain' => 'required|string',
            'remark' => 'required|string',
            'cdnDomain' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->cdnService->getCdnAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * cdn列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCdnList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->cdnService->getCdnList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑cdn
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCdnEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'originSite' => 'required|string',
            'useDomain' => 'required|string',
            'remark' => 'required|string',
            'cdnDomain' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->cdnService->getCdnEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除cdn
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCdnDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'originSite' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->cdnService->getCdnDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

}
