<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Cloud\ICloudService;

class CloudController extends BaseController
{
    private $time;
    private $cloudService;

    public function __construct(ICloudService $cloudService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->cloudService = $cloudService;
    }

    /**
     * 新增云平台账号
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCloudAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'cloudName' => 'required|string',
            'accountName' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->cloudService->getCloudAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 云平台列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCloudList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->cloudService->getCloudList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑云平台账号
     * @return array
     * @date 2020/11/16
     * @author live
     */
    public function getCloudEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'cloudName' => 'required|string',
            'accountName' => 'required|string',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->cloudService->getCloudEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除云平台账号
     * @return array
     * @date 2020/11/16
     * @author live
     */
    public function getCloudDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'cloudName' => 'required|string',
            'accountName' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->cloudService->getCloudDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 下拉框列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCloudSelectList(Request $request)
    {
        try {
            $data = $this->cloudService->getCloudSelectList();
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

}

