<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Cvm\ICvmService;

class CvmController extends BaseController
{
    private $time;
    private $cvmService;

    public function __construct(ICvmService $cvmService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->cvmService = $cvmService;
    }

    /**
     * cvm列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCvmList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->cvmService->getCvmList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除cvm
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getCvmDel(Request $request){
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceId' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->cvmService->getCvmDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 新增cvm
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getCvmAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'system' => 'required|string',
            'publicId' => 'required|string',
            'intranetId' => 'required|string',
            'capacity' => 'required|string',
            'payType' => 'required|numeric',
            'networkType' => 'required|numeric',
            'region' => 'required|string',
            'config' => 'required|string',
            'expireTime' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->cvmService->getCvmAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑cvm
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getCvmEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'system' => 'required|string',
            'publicId' => 'required|string',
            'intranetId' => 'required|string',
            'capacity' => 'required|string',
            'payType' => 'required|numeric',
            'networkType' => 'required|numeric',
            'region' => 'required|string',
            'config' => 'required|string',
            'expireTime' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->cvmService->getCvmEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }
}
