<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Records\IRecordsService;

class DomainRecordsController extends BaseController
{
    private $time;
    private $recordsService;

    public function __construct(IRecordsService $recordsService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->recordsService = $recordsService;
    }

    /**
     * 新增记录
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRecordsAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'record' => 'required|string',
            'recordType' => 'required|numeric',
            'ispLine' => 'required|numeric',
            'recordValue' => 'required|string',
            'remark' => 'required|string',
            'domainId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->recordsService->getRecordsAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 记录列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRecordsList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->recordsService->getRecordsList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑记录
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function geRecordsEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'record' => 'required|string',
            'recordType' => 'required|numeric',
            'ispLine' => 'required|numeric',
            'recordValue' => 'required|string',
            'remark' => 'required|string',
            'domainId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);

        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->recordsService->getRecordsEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除记录
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRecordsDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'record' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->recordsService->getRecordsDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

}

