<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Domains\IDomainsService;

class DomainsController extends BaseController
{
    private $time;
    private $domainsService;

    public function __construct(IDomainsService $domainsService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->domainsService = $domainsService;
    }

    /**
     * 新增域名
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getDomainsAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'name' => 'required|string',
            'registrant' => 'required|string',
            'registrantEmail' => 'required|email',
            'registrar' => 'required|numeric',
            'expireDate' => 'required|string',
            'beianInfo' => 'required|string',
            'hoster' => 'required|numeric',
            'projectId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->domainsService->getDomainsAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 域名列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getDomainsList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->domainsService->getDomainsList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑域名
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getDomainsEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'name' => 'required|string',
            'registrant' => 'required|string',
            'registrantEmail' => 'required|email',
            'registrar' => 'required|numeric',
            'expireDate' => 'required|string',
            'beianInfo' => 'required|string',
            'hoster' => 'required|numeric',
            'projectId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->domainsService->getDomainsEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除域名
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getDomainsDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'name' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->domainsService->getDomainsDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 域名下拉列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getDomainsSelectList()
    {
        try {
            $data = $this->domainsService->getDomainsSelectList();
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

}
