<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Options\IOptionsService;

class OptionsController extends BaseController
{
    private $time;
    private $optionsService;

    public function __construct(IOptionsService $optionsService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->optionsService = $optionsService;
    }

    /**
     * 新增选项卡
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getOptionsAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'itemTag' => 'required|string',
            'itemKey' => 'required|string',
            'itemValue' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->optionsService->getOptionsAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 选项卡列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getOptionsList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->optionsService->getOptionsList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑选项卡
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getOptionsEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'itemTag' => 'required|string',
            'itemKey' => 'required|string',
            'itemValue' => 'required|string'

        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->optionsService->geOptionsEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除选项卡
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getOptionsDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'itemKey' => 'required|string',
            'itemValue' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->optionsService->getOptionsDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 获取选项卡下拉
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getOptionsSelectList(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'itemTag' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->optionsService->getOptionsSelectList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }
}

