<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Project\IProjectService;

class ProjectController extends BaseController
{
    private $time;
    private $projectService;

    public function __construct(IProjectService $projectService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->projectService = $projectService;
    }

    /**
     * 新增项目
     * @return array
     * @date 2020/11/17
     * @author live
     */
    public function getProjectAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'cnName' => 'required|string',
            'enName' => 'required|string',
            'mainMaster' => 'required|string',
            'devMaster' => 'required|string',
            'email' => 'required|email',
            'phone' => 'required|regex:/^1[345789][0-9]{9}$/'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->projectService->getProjectAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 项目列表
     * @return array
     * @date 2020/11/16
     * @author live
     */
    public function getProjectList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->projectService->getProjectList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑项目
     * @return array
     * @date 2020/11/16
     * @author live
     */
    public function getProjectEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'cnName' => 'required|string',
            'enName' => 'required|string',
            'mainMaster' => 'required|string',
            'devMaster' => 'required|string',
            'email' => 'required|email',
            'phone' => 'required|regex:/^1[345789][0-9]{9}$/',
            'createdAt' =>  'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->projectService->getProjectEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除项目
     * @return array
     * @date 2020/11/16
     * @author live
     */
    public function getProjectDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'enName' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->projectService->getProjectDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 项目下拉框列表
     * @return array
     * @date 2020/11/17
     * @author live
     */
    public function getProjectSelectList(Request $request)
    {
        try {
            $data = $this->projectService->getProjectSelectList();
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

}
