<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Rdb\IRdbService;

class RdbController extends BaseController
{
    private $time;
    private $rdbService;

    public function __construct(IRdbService $rdbService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->rdbService = $rdbService;
    }

    /**
     * rdb列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRdbList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->rdbService->getRdbList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除rdb
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRdbDel(Request $request){
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceId' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->rdbService->getRdbDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 新增rdb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRdbAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'type' => 'required|string',
            'mysqlType' => 'required|string',
            'capacity' => 'required|string',
            'payType' => 'required|numeric',
            'networkType' => 'required|numeric',
            'region' => 'required|string',
            'expireTime' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->rdbService->getRdbAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑rdb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRdbEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'type' => 'required|string',
            'mysqlType' => 'required|string',
            'capacity' => 'required|string',
            'payType' => 'required|numeric',
            'networkType' => 'required|numeric',
            'region' => 'required|string',
            'expireTime' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->rdbService->getRdbEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }
}
