<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Redis\IRedisService;

class RedisController extends BaseController
{
    private $time;
    private $redisService;

    public function __construct(IRedisService $redisService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->redisService = $redisService;
    }

    /**
     * redis列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRedisList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->redisService->getRedisList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除redis
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getRedisDel(Request $request){
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceId' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->redisService->getRedisDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 新增redis
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRedisAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'capacity' => 'required|string',
            'quota' => 'required|string',
            'edition' => 'required|string',
            'norms' => 'required|string',
            'payType' => 'required|numeric',
            'networkType' => 'required|numeric',
            'region' => 'required|string',
            'expireTime' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->redisService->getRedisAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑redis
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRedisEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'capacity' => 'required|string',
            'quota' => 'required|string',
            'edition' => 'required|string',
            'norms' => 'required|string',
            'payType' => 'required|numeric',
            'networkType' => 'required|numeric',
            'region' => 'required|string',
            'expireTime' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->redisService->getRedisEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }
}
