<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Slb\ISlbService;

class SlbController extends BaseController
{
    private $time;
    private $slbService;

    public function __construct(ISlbService $slbService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->slbService = $slbService;
    }

    /**
     * slb列表
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getSlbList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->slbService->getSlbList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除slb
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getSlbDel(Request $request){
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceId' => 'required|string'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->slbService->getSlbDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 新增slb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getSlbAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'outerIp' => 'required|string',
            'backendIpList' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->slbService->getSlbAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 编辑slb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getSlbEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'instanceName' => 'required|string',
            'instanceId' => 'required|string',
            'outerIp' => 'required|string',
            'backendIpList' => 'required|string',
            'cloudId' => 'required|numeric',
            'projectId' => 'required|numeric',
            'createdAt' => 'required|string'
        ]);
        if($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->slbService->getSlbEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

}
