<?php
namespace App\Services\Cdn;

use App\Models\CdnModel;
use App\Services\Cdn\ICdnService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class CdnService implements ICdnService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增cdn
     * @return int
     * @date 2020/11/18
     * @author live
     */

    public function getCdnAdd($postData)
    {
        $row = new CdnModel();
        $row->origin_site = $postData['originSite'] ?? '';
        $row->use_domain = $postData['useDomain'] ?? '';
        $row->remark = $postData['remark'] ?? '';
        $row->cdn_domain = $postData['cdnDomain'] ?? '';
        $row->cloud_id = $postData['cloudId'] ?? '';
        $row->project_id = $postData['projectId'] ?? '';
        $row->created_at = $postData['createdAt'] ?? $this->time;
        if( $row->save()) return $row->id;
        throw new Exception(config('msg.cdn.5001'),5001);

    }


    /**
     * cdn列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getCdnList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];
        $originSite = $postData['originSite']??'';
        $cloudId = $postData['cloudId']??0;
        $projectId = $postData['projectId']??0;
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $cdns = CdnModel::with(['getRelationProject:id,cn_name,en_name','getCloudProject:id,cloud_name,account_name'])->when($originSite != '', function ($query) use ($originSite) {
            return $query->where('origin_site', 'like',$originSite.'%');
        })->when($cloudId > 0, function ($query) use ($cloudId) {
            return $query->where('cloud_id',$cloudId);
        })->when($projectId > 0, function ($query) use ($projectId) {
            return $query->where('project_id',$projectId);
        })->select('id','origin_site','use_domain','remark','cdn_domain','cloud_id','project_id','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $cdns->total();
        $array['totalPage'] = $cdns->lastPage();
        foreach($cdns as $cdn){
            $tem['id'] = $cdn->id;
            $tem['originSite'] = $cdn->origin_site;
            $tem['useDomain'] = $cdn->use_domain;
            $tem['remark'] = $cdn->remark;
            $tem['cdnDomain'] = $cdn->cdn_domain;
            $tem['projectId'] = $cdn->project_id;
            $tem['projecCnName'] = $cdn->getRelationProject->cn_name ?? '';
            $tem['projecEnName'] = $cdn->getRelationProject->en_name ?? '';
            $tem['cloudId'] = $cdn->cloud_id;
            $tem['cloudName'] = $cdn->getCloudProject->cloud_name ?? '';
            $tem['cloudAccount'] = $cdn->getCloudProject->account_name ?? '';
            $tem['created_at'] = Carbon::parse($cdn->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($cdns,$cdn,$tem);
        return $array;
    }

    /**
     * cdn编辑
     * @return int
     * @date 2020/10/18
     * @author live
     */
    public function getCdnEdit($postData)
    {
        $cdn = CdnModel::find($postData['id']);
        if(!$cdn) throw new Exception(config('msg.cdn.5002'),5002);
        $cdn->origin_site = $postData['originSite'] ?? '';
        $cdn->use_domain = $postData['useDomain'] ?? '';
        $cdn->remark = $postData['remark'] ?? '';
        $cdn->cdn_domain = $postData['cdnDomain'] ?? '';
        $cdn->cloud_id = $postData['cloudId'] ?? '';
        $cdn->project_id = $postData['projectId'] ?? '';
        $cdn->created_at = $postData['createdAt'];
        if($cdn->save()) return $cdn->id;
        throw new Exception(config('msg.cdn.5003'),5003);

    }

    /**
     * 删除cdn
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getCdnDel($postData)
    {
        $cdn = CdnModel::where('id',$postData['id'])->where('origin_site',$postData['originSite'])->first();
        if(!$cdn) throw new Exception(config('msg.cdn.5002'),5002);
        if($cdn->delete()) return true;
        throw new Exception(config('msg.cdn.5004'),5004);
    }
}

