<?php
namespace App\Services\Cloud;

use App\Models\CloudModel;
use App\Services\Cloud\ICloudService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class CloudService implements ICloudService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增云平台
     * @return int
     * @date 2020/11/18
     * @author live
     */
    public function getCloudAdd($postData)
    {
        $verity = self::getVerityRepeatCloud(0,$postData['cloudName'],$postData['accountName']);
        if($verity){
            $row = new CloudModel();
            $row->cloud_name = $postData['cloudName'] ?? '';
            $row->account_name = $postData['accountName'] ?? '';
            $row->created_at = $postData['createdAt'] ?? $this->time;
            if( $row->save()) return $row->id;
            throw new Exception(config('msg.cloud.4002'),4002);
        }
        throw new Exception(config('msg.cloud.4001'),4001);
    }

    /**
     * 检验云平台账号重复性
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public static function getVerityRepeatCloud($id,$cloudName,$accountName)
    {
        $verity = CloudModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where('cloud_name',$cloudName)->where('account_name',$accountName)->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 云平台账号列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getCloudList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];
        $key = $postData['key']??'';
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $clouds = CloudModel::when($key != '', function ($query) use ($key) {
            return $query->where('cloud_name', 'like',$key.'%')->orWhere('account_name', 'like',$key.'%');
        })->select('id','cloud_name','account_name','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $clouds->total();
        $array['totalPage'] = $clouds->lastPage();
        foreach($clouds as $cloud){
            $tem['id'] = $cloud->id;
            $tem['cloudName'] = $cloud->cloud_name;
            $tem['accountName'] = $cloud->account_name;
            $tem['created_at'] = Carbon::parse($cloud->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($clouds,$cloud,$tem);
        return $array;
    }

    /**
     * 云平台账号编辑
     * @return int
     * @date 2020/10/18
     * @author live
     */
    public function getCloudEdit($postData)
    {
        $verity = self::getVerityRepeatCloud($postData['id'],$postData['cloudName'],$postData['accountName']);
        if($verity){
            $cloud = CloudModel::find($postData['id']);
            if(!$cloud) throw new Exception(config('msg.project.4003'),4003);
            $cloud->cloud_name = $postData['cloudName'];
            $cloud->account_name = $postData['accountName'];
            $cloud->created_at = $postData['createdAt'];
            if($cloud->save()) return $cloud->id;
            throw new Exception(config('msg.cloud.4004'),4004);
        }
        throw new Exception(config('msg.cloud.4001'),4001);
    }

    /**
     * 删除云平台账号
     * @return bool
     * @date 2020/10/17
     * @author live
     */
    public function getCloudDel($postData)
    {
        $cloud = CloudModel::where('id',$postData['id'])->where('cloud_name',$postData['cloudName'])->where('account_name',$postData['accountName'])->first();
        if(!$cloud) throw new Exception(config('msg.cloud.4003'),4003);
        if($cloud->delete()) return true;
        throw new Exception(config('msg.cloud.4005'),4005);
    }

    /**
     * 下拉框列表
     * @return array
     * @date 2020/10/17
     * @author live
     */
    public function getCloudSelectList()
    {
        $clouds = CloudModel::select('id','cloud_name as cloudName','account_name as accountName')->orderBy('id','DESC')->get()->toArray();
        return $clouds;
    }
}
