<?php
namespace App\Services\Cvm;

use App\Models\CvmModel;
use App\Services\Cvm\ICvmService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class CvmService implements ICvmService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * cvm列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getCvmList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];

        $instanceName = $postData['instanceName']??'';
        $payType = $postData['payType']??'';
        $networkType = $postData['networkType']??'';
        $cloudId = $postData['cloudId']??0;
        $projectId = $postData['projectId']??0;

        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $cvms = CvmModel::with(['getRelationProject:id,cn_name,en_name','getCloudProject:id,cloud_name,account_name','getRelationPayType:id,item_value','getRelationNetworkType:id,item_value'])->when($instanceName != '', function ($query) use ($instanceName) {
            return $query->where('instance_name', 'like',$instanceName.'%');
        })->when($payType > 0, function ($query) use ($payType) {
            return $query->where('pay_type',$payType);
        })->when($networkType > 0, function ($query) use ($networkType) {
            return $query->where('network_type',$networkType);
        })->when($cloudId > 0, function ($query) use ($cloudId) {
            return $query->where('cloud_id',$cloudId);
        })->when($projectId > 0, function ($query) use ($projectId) {
            return $query->where('project_id',$projectId);
        })->select('id','instance_name','instance_id','system','public_id','intranet_id','capacity','pay_type','network_type','region','config','expire_time','cloud_id','project_id','created_at')->orderBy('expire_time','ASC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);
        $array['totalNum'] = $cvms->total();
        $array['totalPage'] = $cvms->lastPage();
        foreach($cvms as $cvm){
            $tem['id'] = $cvm->id;
            $tem['instanceName'] = $cvm->instance_name;
            $tem['instanceId'] = $cvm->instance_id;
            $tem['system'] = $cvm->system;
            $tem['publicId'] = $cvm->public_id;
            $tem['intranetId'] = $cvm->intranet_id;
            $tem['capacity'] = $cvm->capacity;
            $tem['payTypeId'] = $cvm->pay_type;
            $tem['payTypeName'] = $cvm->getRelationPayType->item_value ?? '';
            $tem['networkTypeId'] = $cvm->network_type;
            $tem['networkTypeName'] = $cvm->getRelationNetworkType->item_value ?? '';
            $tem['region'] = $cvm->region;
            $tem['config'] = $cvm->config;
            $tem['expire_time'] = $cvm->expire_time;
            $tem['projectId'] = $cvm->project_id;
            $tem['projecCnName'] = $cvm->getRelationProject->cn_name ?? '';
            $tem['projecEnName'] = $cvm->getRelationProject->en_name ?? '';
            $tem['cloudId'] = $cvm->cloud_id;
            $tem['cloudName'] = $cvm->getCloudProject->cloud_name ?? '';
            $tem['cloudAccount'] = $cvm->getCloudProject->account_name ?? '';
            $tem['created_at'] = Carbon::parse($cvm->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($cvms,$cvm,$tem);
        return $array;
    }

    /**
     * 删除cvm
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getCvmDel($postData)
    {
        $cvm = CvmModel::where('id',$postData['id'])->where('instance_id',$postData['instanceId'])->first();
        if(!$cvm) throw new Exception(config('msg.cvm.1303'),1303);
        if($cvm->delete()) return true;
        throw new Exception(config('msg.cvm.1305'),1305);
    }

    /**
     * 新增cvm
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getCvmAdd($postData)
    {
        $verity = self::getVerityRepeatCvm(0,$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.cvm.1302'), 1302);
        $row = new CvmModel();
        $row->instance_name = $postData['instanceName'] ?? '';
        $row->instance_id = $postData['instanceId'] ?? '';
        $row->system = $postData['system'] ?? '';
        $row->public_id = $postData['publicId'] ?? '';
        $row->intranet_id = $postData['intranetId'] ?? '';
        $row->capacity = $postData['capacity'] ?? '';
        $row->pay_type = $postData['payType'] ?? '';
        $row->network_type = $postData['networkType'] ?? '';
        $row->region = $postData['region'] ?? '';
        $row->config = $postData['config'] ?? '';
        $row->expire_time = $postData['expireTime'] ?? '';
        $row->cloud_id = $postData['cloudId'] ?? 0;
        $row->project_id = $postData['projectId'] ?? 0;
        $row->created_at = $postData['createdAt'] ?? $this->time;
        if ($row->save()) return $row->id;
        throw new Exception(config('msg.cvm.1301'), 1301);
    }

    /**
     * 验证cvm重复性
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public static function getVerityRepeatCvm($id,$instanceName,$instanceId)
    {
        $verity = CvmModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where(function ($query) use ($instanceName,$instanceId) {
            return $query->where('instance_name', $instanceName)->orWhere('instance_id',$instanceId);
        })->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 编辑cvm
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public function getCvmEdit($postData)
    {
        $verity = self::getVerityRepeatCvm($postData['id'],$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.cvm.1302'), 1302);
        $cvm = CvmModel::find($postData['id']);
        if(!$cvm) throw new Exception(config('msg.cvm.1303'),1303);
        $cvm->instance_name = $postData['instanceName'] ?? '';
        $cvm->instance_id = $postData['instanceId'] ?? '';
        $cvm->system = $postData['system'] ?? '';
        $cvm->public_id = $postData['publicId'] ?? '';
        $cvm->intranet_id = $postData['intranetId'] ?? '';
        $cvm->capacity = $postData['capacity'] ?? '';
        $cvm->pay_type = $postData['payType'] ?? '';
        $cvm->network_type = $postData['networkType'] ?? '';
        $cvm->region = $postData['region'] ?? '';
        $cvm->config = $postData['config'] ?? '';
        $cvm->expire_time = $postData['expireTime'] ?? '';
        $cvm->cloud_id = $postData['cloudId'];
        $cvm->project_id = $postData['projectId'];
        $cvm->created_at = $postData['createdAt'];
        if($cvm->save()) return $cvm->id;
        throw new Exception(config('msg.cvm.1304'),1304);
    }
}
