<?php
namespace App\Services\Domains;

use App\Models\DomainsModel;
use App\Services\Domains\IDomainsService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;
use App\Services\Records\RecordsService;
use App\Models\DomainRecordsModel;

class DomainsService implements IDomainsService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增域名
     * @return int
     * @date 2020/11/18
     * @author live
     */

    public function getDomainsAdd($postData)
    {
        $verity = self::getVerityRepeatDomains(0,$postData['name']);
        if($verity){
            $row = new DomainsModel();
            $row->name = $postData['name'] ?? '';
            $row->registrant = $postData['registrant'] ?? '';
            $row->registrant_email = $postData['registrantEmail'] ?? '';
            $row->registrar = $postData['registrar'] ?? '';
            $row->expire_date = $postData['expireDate'] ?? '';
            $row->beian_info = $postData['beianInfo'] ?? '';
            $row->hoster = $postData['hoster'] ?? '';
            $row->project_id = $postData['projectId'] ?? 0;
            $row->created_at = $postData['createdAt'] ?? $this->time;
            if( $row->save()) return $row->id;
            throw new Exception(config('msg.domains.7001'),7001);
        }
        throw new Exception(config('msg.domains.7002'),7002);

    }

    /**
     * 验证域名重复性
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public static function getVerityRepeatDomains($id,$name)
    {
        $verity = DomainsModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where('name',$name)->select('id')->first();
        if($verity) return false;
        return true;
    }
    /**
     * 域名列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getDomainsList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];
        $name = $postData['name']??'';
        $registrant = $postData['registrant']??'';
        $registrar = $postData['registrar']??0;
        $hoster = $postData['hoster']??0;
        $projectId = $postData['projectId']??0;
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $domains = DomainsModel::with(['getRelationRegistrar:id,item_value','getRelationHoster:id,item_value','getRelationProject:id,cn_name,en_name'])->when($name != '', function ($query) use ($name) {
            return $query->where('name', 'like',$name.'%');
        })->when($registrant != '', function ($query) use ($registrant) {
            return $query->where('registrant', 'like',$registrant.'%');
        })->when($registrar > 0, function ($query) use ($registrar) {
            return $query->where('registrar',$registrar);
        })->when($hoster > 0, function ($query) use ($hoster) {
            return $query->where('hoster',$hoster);
        })->when($projectId > 0, function ($query) use ($projectId) {
            return $query->where('project_id',$projectId);
        })->select('id','name','registrant','registrant_email','registrar','expire_date','beian_info','hoster','project_id','created_at')->orderBy('expire_date','ASC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);
        $array['totalNum'] = $domains->total();
        $array['totalPage'] = $domains->lastPage();

        $ids = [];
        $domainArray = [];
        foreach($domains as $domain){
            $tem['id'] = $domain->id;
            $tem['name'] = $domain->name;
            $tem['registrant'] = $domain->registrant;
            $tem['registrant_email'] = $domain->registrant_email;
            $tem['registrarId'] = $domain->registrar;
            $tem['registrar'] = $domain->getRelationRegistrar->item_value ?? '';
            $tem['expireDate'] = $domain->expire_date;
            $tem['beianInfo'] = $domain->beian_info;
            $tem['hosterId'] = $domain->hoster;
            $tem['hoster'] = $domain->getRelationHoster->item_value ?? '';
            $tem['projecId'] = $domain->project_id;
            $tem['projecCnName'] = $domain->getRelationProject->cn_name ?? '';
            $tem['projecEnName'] = $domain->getRelationProject->en_name ?? '';
            $tem['created_at'] = Carbon::parse($domain->created_at)->format('Y-m-d H:i:s');
            $tem['childrens'] = [];
            $domainArray[$domain->id] = $tem;
            $ids[] = $domain->id;
        }

        $records = RecordsService::getDomainRecords($ids);
        foreach($domainArray as $key=>$val){
            $val['childrens'] = $records[$key] ?? [];
            $array['data'][] = $val;
        }
        unset($cdns,$cdn,$tem,$ids,$records,$domainArray,$val);
        return $array;
    }

    /**
     * 域名编辑
     * @return int
     * @date 2020/10/18
     * @author live
     */
    public function getDomainsEdit($postData)
    {
        $verity = self::getVerityRepeatDomains($postData['id'],$postData['name']);
        if(!$verity)  throw new Exception(config('msg.domains.7002'),7002);
        $domain = DomainsModel::find($postData['id']);
        if(!$domain) throw new Exception(config('msg.domains.7003'),7003);
        $domain->name = $postData['name'] ?? '';
        $domain->registrant = $postData['registrant'] ?? '';
        $domain->registrant_email = $postData['registrantEmail'] ?? '';
        $domain->registrar = $postData['registrar'] ?? '';
        $domain->expire_date = $postData['expireDate'] ?? '';
        $domain->beian_info = $postData['beianInfo'] ?? '';
        $domain->hoster = $postData['hoster'] ?? '';
        $domain->project_id = $postData['projectId'] ?? 0;
        $domain->created_at = $postData['createdAt'];
        if($domain->save()) return $domain->id;
        throw new Exception(config('msg.domains.7004'),7004);

    }

    /**
     * 删除域名
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getDomainsDel($postData)
    {
        $domain = DomainsModel::where('id',$postData['id'])->where('name',$postData['name'])->first();
        if(!$domain) throw new Exception(config('msg.domains.7003'),7003);
        $verity = DomainRecordsModel::where('domain_id',$postData['id'])->select('id')->first();
        if($verity) throw new Exception(config('msg.domains.7006'),7006);
        if($domain->delete()) return true;
        throw new Exception(config('msg.domains.7005'),7005);
    }

    /**
     * 域名下拉列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getDomainsSelectList()
    {
        $domains = DomainsModel::select('id','name')->orderBy('id','DESC')->get()->toArray();
        return $domains;
    }
}
