<?php
namespace App\Services\Options;

use App\Models\OptionsModel;
use App\Services\Options\IOptionsService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class OptionsService implements IOptionsService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增选项卡
     * @return array
     * @date 2020/11/18
     * @author live
     */
    public function getOptionsAdd($postData)
    {
        $verity = self::getVerityRepeatOptions(0,$postData['itemKey'],$postData['itemValue']);
        if($verity){
            $row = new OptionsModel();
            $row->item_key = $postData['itemKey'] ?? '';
            $row->item_value = $postData['itemValue'] ?? '';
            $row->item_tag = $postData['itemTag'] ?? '';
            if( $row->save()) return $row->id;
            throw new Exception(config('msg.options.6001'),6001);
        }
        throw new Exception(config('msg.options.6002'),6002);
    }

    /**
     * 验证选项卡重复性
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public static function getVerityRepeatOptions($id,$itemKey,$itemValue)
    {
        $verity = OptionsModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where('item_key',$itemKey)->where('item_value',$itemValue)->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 选项卡列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getOptionsList($postData)
    {
        $array = [];
        $itemTag = $postData['itemTag']??'';
        $options = OptionsModel::when($itemTag != '', function ($query) use ($itemTag) {
            return $query->where('item_tag', 'like',$itemTag.'%');
        })->select('id','item_key','item_value','item_tag','created_at')->orderBy('id','DESC')->get();

        foreach($options as $option){
            $tem['id'] = $option->id;
            $tem['itemKey'] = $option->item_key;
            $tem['itemValue'] = $option->item_value;
            $tem['created_at'] = Carbon::parse($option->created_at)->format('Y-m-d H:i:s');
            $array[$option->item_tag]['tag'] = $option->item_tag;
            $array[$option->item_tag]['content'][] = $tem;
        }
        $array = array_values($array);
        unset($options,$option,$tem);
        return $array;
    }

    /**
     * 选项卡编辑
     * @return int
     * @date 2020/10/18
     * @author live
     */
    public function geOptionsEdit($postData)
    {
        $option = OptionsModel::find($postData['id']);
        if(!$option) throw new Exception(config('msg.options.6003'),6003);
        $option->item_key = $postData['itemKey'] ?? '';
        $option->item_value = $postData['itemValue'] ?? '';
        $option->item_tag = $postData['itemTag'] ?? '';
        if($option->save()) return $option->id;
        throw new Exception(config('msg.options.6004'),6004);

    }

    /**
     * 删除选项卡
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getOptionsDel($postData)
    {
        $option = OptionsModel::where('id',$postData['id'])->where('item_key',$postData['itemKey'])->where('item_value',$postData['itemValue'])->first();
        if(!$option) throw new Exception(config('msg.options.6003'),6003);
        if($option->delete()) return true;
        throw new Exception(config('msg.options.6005'),6005);
    }

    /**
     * 选项卡下拉
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getOptionsSelectList($postData){
        $itemTags = explode('#',$postData['itemTag']);
        $options = OptionsModel::whereIn('item_tag',$itemTags)->select('id','item_key','item_value','item_tag')->get();
        foreach($options as $option){
            $tem['id'] = $option->id;
            $tem['itemKey'] = $option->item_key;
            $tem['itemValue'] = $option->item_value;
            $array[$option->item_tag][] = $tem;
        }
        unset($options,$option,$tem);
        return $array;
    }
}
