<?php
namespace App\Services\Project;

use App\Services\Project\IProjectService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use App\Models\ProjectModel;
use Illuminate\Support\Facades\Cache;

class ProjectService implements IProjectService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增项目
     * @return array
     * @date 2020/11/17
     * @author live
     */
    public function getProjectAdd($postData)
    {
        $verity = self::getVerityRepeatProject(0,$postData['cnName'],$postData['enName']);
        if($verity){
            $row = new ProjectModel();
            $row->cn_name = $postData['cnName'] ?? '';
            $row->en_name = $postData['enName'] ?? '';
            $row->main_master = $postData['mainMaster'] ?? '';
            $row->dev_master = $postData['devMaster'] ?? '';
            $row->email =$postData['email'];
            $row->phone = $postData['phone'];
            $row->created_at = $postData['createdAt'] ?? $this->time;
            if( $row->save()) return $row->id;
            throw new Exception(config('msg.project.3002'),3002);
        }
        throw new Exception(config('msg.project.3001'),3001);
    }

    /**
     * 检验项目重复性
     * @return bool
     * @date 2020/10/17
     * @author live
     */
    public static function getVerityRepeatProject($id,$cnName,$enName)
    {
        $verity = ProjectModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where(function ($query) use ($cnName,$enName) {
            return $query->where('cn_name', $cnName)->orWhere('en_name',$enName);
        })->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 项目列表
     * @return array
     * @date 2020/10/17
     * @author live
     */
    public function getProjectList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];
        $key = $postData['key']??'';
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $projects = ProjectModel::when($key != '', function ($query) use ($key) {
            return $query->where('cn_name', 'like',$key.'%')->orWhere('en_name', 'like',$key.'%')->orWhere('main_master', 'like',$key.'%')->orWhere('dev_master', 'like',$key.'%')->orWhere('email', 'like',$key.'%');
        })->select('id','cn_name','en_name','main_master','dev_master','email','phone','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $projects->total();
        $array['totalPage'] = $projects->lastPage();
        foreach($projects as $pro){
            $tem['id'] = $pro->id;
            $tem['cnName'] = $pro->cn_name;
            $tem['enName'] = $pro->en_name;
            $tem['mainMaster'] = $pro->main_master;
            $tem['devMaster'] = $pro->dev_master;
            $tem['email'] = $pro->email;
            $tem['phone'] = $pro->phone;
            $tem['created_at'] = Carbon::parse($pro->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($projects,$pro,$tem);
        return $array;
    }

    /**
     * 项目编辑
     * @return int
     * @date 2020/10/17
     * @author live
     */
    public function getProjectEdit($postData)
    {
        $verity = self::getVerityRepeatProject($postData['id'],$postData['cnName'],$postData['enName']);
        if($verity){
            $project = ProjectModel::find($postData['id']);
            if(!$project) throw new Exception(config('msg.project.3003'),3003);

            $project->cn_name = $postData['cnName'];
            $project->en_name = $postData['enName'];
            $project->main_master = $postData['mainMaster'];
            $project->dev_master = $postData['devMaster'];
            $project->email = $postData['email'];
            $project->phone = $postData['phone'];
            $project->created_at = $postData['createdAt'];
            if($project->save()) return $project->id;
            throw new Exception(config('msg.user.3004'),3004);
        }
        throw new Exception(config('msg.project.3001'),3001);
    }

    /**
     * 删除项目
     * @return bool
     * @date 2020/10/17
     * @author live
     */
    public function getProjectDel($postData)
    {
        $project = ProjectModel::where('id',$postData['id'])->where('en_name',$postData['enName'])->first();
        if(!$project) throw new Exception(config('msg.project.3003'),3003);
        if($project->delete()) return true;
        throw new Exception(config('msg.project.3005'),3005);
    }

    /**
     * 下拉框列表
     * @return array
     * @date 2020/10/17
     * @author live
     */
    public function getProjectSelectList()
    {
        $projects = ProjectModel::select('id','cn_name as cnName','en_name as enName')->orderBy('id','DESC')->get()->toArray();
        return $projects;
    }
}
