<?php
namespace App\Services\Rdb;

use App\Models\RdbModel;
use App\Services\Rdb\IRdbService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class RdbService implements IRdbService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * rdb列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getRdbList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];

        $instanceName = $postData['instanceName']??'';
        $cloudId = $postData['cloudId']??0;
        $payType = $postData['payType']??'';
        $networkType = $postData['networkType']??'';
        $projectId = $postData['projectId']??0;
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $rdbs = RdbModel::with(['getRelationProject:id,cn_name,en_name','getCloudProject:id,cloud_name,account_name','getRelationPayType:id,item_value','getRelationNetworkType:id,item_value'])->when($instanceName != '', function ($query) use ($instanceName) {
            return $query->where('instance_name', 'like',$instanceName.'%');
        })->when($payType > 0, function ($query) use ($payType) {
            return $query->where('pay_type',$payType);
        })->when($networkType > 0, function ($query) use ($networkType) {
            return $query->where('network_type',$networkType);
        })->when($cloudId > 0, function ($query) use ($cloudId) {
            return $query->where('cloud_id',$cloudId);
        })->when($projectId > 0, function ($query) use ($projectId) {
            return $query->where('project_id',$projectId);
        })->select('id','instance_name','instance_id','type','mysql_type','capacity','pay_type','network_type','region','expire_time','cloud_id','project_id','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $rdbs->total();
        $array['totalPage'] = $rdbs->lastPage();
        foreach($rdbs as $rdb){
            $tem['id'] = $rdb->id;
            $tem['instanceName'] = $rdb->instance_name;
            $tem['instanceId'] = $rdb->instance_id;
            $tem['type'] = $rdb->type;
            $tem['mysqlType'] = $rdb->mysql_type;
            $tem['capacity'] = $rdb->capacity;
            $tem['payTypeId'] = $rdb->pay_type;
            $tem['payTypeName'] = $rdb->getRelationPayType->item_value ?? '';
            $tem['networkTypeId'] = $rdb->network_type;
            $tem['networkTypeName'] = $rdb->getRelationNetworkType->item_value ?? '';
            $tem['region'] = $rdb->region;
            $tem['expire_time'] = $rdb->expire_time;
            $tem['projectId'] = $rdb->project_id;
            $tem['projecCnName'] = $rdb->getRelationProject->cn_name ?? '';
            $tem['projecEnName'] = $rdb->getRelationProject->en_name ?? '';
            $tem['cloudId'] = $rdb->cloud_id;
            $tem['cloudName'] = $rdb->getCloudProject->cloud_name ?? '';
            $tem['cloudAccount'] = $rdb->getCloudProject->account_name ?? '';
            $tem['created_at'] = Carbon::parse($rdb->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($rdbs,$rdb,$tem);
        return $array;
    }

    /**
     * 删除rdb
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getRdbDel($postData)
    {
        $rdb = RdbModel::where('id',$postData['id'])->where('instance_id',$postData['instanceId'])->first();
        if(!$rdb) throw new Exception(config('msg.rdb.1103'),1103);
        if($rdb->delete()) return true;
        throw new Exception(config('msg.rdb.1105'),1105);
    }

    /**
     * 新增rdb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRdbAdd($postData)
    {
        $verity = self::getVerityRepeatRdb(0,$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.rdb.1102'), 1102);
        $row = new RdbModel();
        $row->instance_name = $postData['instanceName'] ?? '';
        $row->instance_id = $postData['instanceId'] ?? '';
        $row->type = $postData['type'] ?? '';
        $row->mysql_type = $postData['mysqlType'] ?? '';
        $row->capacity = $postData['capacity'] ?? '';
        $row->pay_type = $postData['payType'] ?? 0;
        $row->network_type = $postData['networkType'] ?? 0;
        $row->region = $postData['region'] ?? '';
        $row->expire_time = $postData['expireTime'] ?? 0;
        $row->cloud_id = $postData['cloudId'] ?? 0;
        $row->project_id = $postData['projectId'] ?? 0;
        $row->created_at = $postData['createdAt'] ?? $this->time;
        if ($row->save()) return $row->id;
        throw new Exception(config('msg.rdb.1101'), 1101);
    }

    /**
     * 验证rdb重复性
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public static function getVerityRepeatRdb($id,$instanceName,$instanceId)
    {
        $verity = RdbModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where(function ($query) use ($instanceName,$instanceId) {
            return $query->where('instance_name', $instanceName)->orWhere('instance_id',$instanceId);
        })->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 编辑rdb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRdbEdit($postData)
    {
        $verity = self::getVerityRepeatRdb($postData['id'],$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.rdb.1102'), 1102);
        $rdb = RdbModel::find($postData['id']);
        if(!$rdb) throw new Exception(config('msg.rdb.1103'),1103);
        $rdb->instance_name = $postData['instanceName'] ?? '';
        $rdb->instance_id = $postData['instanceId'] ?? '';
        $rdb->type = $postData['type'] ?? '';
        $rdb->mysql_type = $postData['mysqlType'] ?? '';
        $rdb->capacity = $postData['capacity'] ?? '';
        $rdb->pay_type = $postData['payType'] ?? 0;
        $rdb->network_type = $postData['networkType'] ?? 0;
        $rdb->region = $postData['region'] ?? '';
        $rdb->expire_time = $postData['expireTime'] ?? 0;
        $rdb->cloud_id = $postData['cloudId'];
        $rdb->project_id = $postData['projectId'];
        $rdb->created_at = $postData['createdAt'];
        if($rdb->save()) return $rdb->id;
        throw new Exception(config('msg.rdb.1104'),1104);
    }
}
