<?php
namespace App\Services\Records;

use App\Models\DomainRecordsModel;
use App\Services\Records\IRecordsService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class RecordsService implements IRecordsService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 批量获取域名下的记录
     * @return array
     * @date 2020/11/24
     * @author live
     */
    public static function getDomainRecords($ids)
    {
        $array = [];
        if(empty($ids)) return $array;
        $records = DomainRecordsModel::with(['getRelationRecordType:id,item_value','getRelationIspLine:id,item_value'])->whereIn('domain_id',$ids)->select('id','record','record_type','isp_line','record_value','remark','domain_id','created_at')->get();
        foreach($records as $rec){
            $tem['id'] = $rec->id;
            $tem['record'] = $rec->record;
            $tem['recordTypeId'] = $rec->record_type;
            $tem['recordTypeName'] = $rec->getRelationRecordType->item_value ?? '';
            $tem['ispLineId'] = $rec->isp_line;
            $tem['ispLineName'] = $rec->getRelationIspLine->item_value ?? '';
            $tem['recordValue'] = $rec->record_value;
            $tem['remark'] = $rec->remark;
            $tem['created_at'] = Carbon::parse($rec->created_at)->format('Y-m-d H:i:s');
            $array[$rec->domain_id][] = $tem;
        }
        unset($records,$rec,$tem);
        return $array;
    }

    /**
     * 新增记录
     * @return array
     * @date 2020/11/18
     * @author live
     */

    public function getRecordsAdd($postData)
    {
        $row = new DomainRecordsModel();
        $row->record = $postData['record'] ?? '';
        $row->record_type = $postData['recordType'] ?? '';
        $row->isp_line = $postData['ispLine'] ?? '';
        $row->record_value = $postData['recordValue'] ?? '';
        $row->remark = $postData['remark'] ?? '';
        $row->domain_id = $postData['domainId'] ?? 0;
        $row->created_at = $postData['createdAt'] ?? $this->time;
        if ($row->save()) return $row->id;
        throw new Exception(config('msg.records.8001'), 8001);
    }


    /**
     * 记录列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getRecordsList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];
        $record = $postData['record']??'';
        $recordType = $postData['recordType']??0;
        $ispLine = $postData['ispLine']??0;
        $domainId = $postData['domainId']??0;
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $records = DomainRecordsModel::with(['getRelationRecordType:id,item_value','getRelationIspLine:id,item_value','getRelationDomain:id,name'])->when($record != '', function ($query) use ($record) {
            return $query->where('record', 'like',$record.'%');
        })->when($recordType > 0, function ($query) use ($recordType) {
            return $query->where('record_type',$recordType);
        })->when($ispLine > 0, function ($query) use ($ispLine) {
            return $query->where('isp_line',$ispLine);
        })->when($domainId > 0, function ($query) use ($domainId) {
            return $query->where('domain_id',$domainId);
        })->select('id','record','record_type','isp_line','record_value','remark','domain_id','created_at')->orderBy('domain_id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $records->total();
        $array['totalPage'] = $records->lastPage();
        foreach($records as $rec){
            $tem['id'] = $rec->id;
            $tem['record'] = $rec->record;
            $tem['recordTypeId'] = $rec->record_type;
            $tem['recordTypeName'] = $rec->getRelationRecordType->item_value ?? '';
            $tem['ispLineId'] = $rec->isp_line;
            $tem['ispLineName'] = $rec->getRelationIspLine->item_value ?? '';
            $tem['recordValue'] = $rec->record_value;
            $tem['remark'] = $rec->remark;
            $tem['domainId'] = $rec->domain_id;
            $tem['domainName'] = $rec->getRelationDomain->name ?? '';
            $tem['created_at'] = Carbon::parse($rec->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($cdns,$cdn,$tem);
        return $array;
    }

    /**
     * 记录编辑
     * @return int
     * @date 2020/10/18
     * @author live
     */
    public function getRecordsEdit($postData)
    {
        $record = DomainRecordsModel::find($postData['id']);
        if(!$record) throw new Exception(config('msg.records.8003'),8003);
        $record->record = $postData['record'] ?? '';
        $record->record_type = $postData['recordType'] ?? '';
        $record->isp_line = $postData['ispLine'] ?? '';
        $record->record_value = $postData['recordValue'] ?? '';
        $record->remark = $postData['remark'] ?? '';
        $record->domain_id = $postData['domainId'] ?? '';
        $record->created_at = $postData['createdAt'];
        if($record->save()) return $record->id;
        throw new Exception(config('msg.records.8004'),8004);

    }

    /**
     * 删除记录
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getRecordsDel($postData)
    {
        $record = DomainRecordsModel::where('id',$postData['id'])->where('record',$postData['record'])->first();
        if(!$record) throw new Exception(config('msg.records.8003'),8003);
        if($record->delete()) return true;
        throw new Exception(config('msg.records.8005'),8005);
    }
}

