<?php
namespace App\Services\Redis;

use App\Models\RedisModel;
use App\Services\Redis\IRedisService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class RedisService implements IRedisService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * cvm列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getRedisList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];
        $instanceName = $postData['instanceName']??'';
        $payType = $postData['payType']??'';
        $networkType = $postData['networkType']??'';
        $cloudId = $postData['cloudId']??0;
        $projectId = $postData['projectId']??0;
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $Redis = RedisModel::with(['getRelationProject:id,cn_name,en_name','getCloudProject:id,cloud_name,account_name','getRelationPayType:id,item_value','getRelationNetworkType:id,item_value'])->when($instanceName != '', function ($query) use ($instanceName) {
            return $query->where('instance_name', 'like',$instanceName.'%');
        })->when($payType > 0, function ($query) use ($payType) {
            return $query->where('pay_type',$payType);
        })->when($networkType > 0, function ($query) use ($networkType) {
            return $query->where('network_type',$networkType);
        })->when($cloudId > 0, function ($query) use ($cloudId) {
            return $query->where('cloud_id',$cloudId);
        })->when($projectId > 0, function ($query) use ($projectId) {
            return $query->where('project_id',$projectId);
        })->select('id','instance_name','instance_id','capacity','quota','edition','norms','pay_type','network_type','region','expire_time','cloud_id','project_id','created_at')->orderBy('expire_time','ASC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $Redis->total();
        $array['totalPage'] = $Redis->lastPage();
        foreach($Redis as $Red){
            $tem['id'] = $Red->id;
            $tem['instanceName'] = $Red->instance_name;
            $tem['instanceId'] = $Red->instance_id;
            $tem['capacity'] = $Red->capacity;
            $tem['quota'] = $Red->capacity;
            $tem['edition'] = $Red->edition;
            $tem['norms'] = $Red->norms;
            $tem['payTypeId'] = $Red->pay_type;
            $tem['payTypeName'] = $Red->getRelationPayType->item_value ?? '';
            $tem['networkTypeId'] = $Red->network_type;
            $tem['networkTypeName'] = $Red->getRelationNetworkType->item_value ?? '';
            $tem['region'] = $Red->region;
            $tem['expire_time'] = $Red->expire_time;
            $tem['projectId'] = $Red->project_id;
            $tem['projecCnName'] = $Red->getRelationProject->cn_name ?? '';
            $tem['projecEnName'] = $Red->getRelationProject->en_name ?? '';
            $tem['cloudId'] = $Red->cloud_id;
            $tem['cloudName'] = $Red->getCloudProject->cloud_name ?? '';
            $tem['cloudAccount'] = $Red->getCloudProject->account_name ?? '';
            $tem['created_at'] = Carbon::parse($Red->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($slbs,$slb,$tem);
        return $array;
    }

    /**
     * 删除redis
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getRedisDel($postData)
    {
        $redis = RedisModel::where('id',$postData['id'])->where('instance_id',$postData['instanceId'])->first();
        if(!$redis) throw new Exception(config('msg.redis.1203'),1203);
        if($redis->delete()) return true;
        throw new Exception(config('msg.redis.1205'),1205);
    }

    /**
     * 新增redis
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getRedisAdd($postData)
    {
        $verity = self::getVerityRepeatRedis(0,$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.redis.1202'), 1202);
        $row = new RedisModel();
        $row->instance_name = $postData['instanceName'] ?? '';
        $row->instance_id = $postData['instanceId'] ?? '';
        $row->capacity = $postData['capacity'] ?? '';
        $row->quota = $postData['quota'] ?? '';
        $row->edition = $postData['edition'] ?? '';
        $row->norms = $postData['norms'] ?? '';
        $row->pay_type = $postData['payType'] ?? 0;
        $row->network_type = $postData['networkType'] ?? 0;
        $row->region = $postData['region'] ?? '';
        $row->expire_time = $postData['expireTime'] ?? '';
        $row->cloud_id = $postData['cloudId'] ?? 0;
        $row->project_id = $postData['projectId'] ?? 0;
        $row->created_at = $postData['createdAt'] ?? $this->time;
        if ($row->save()) return $row->id;
        throw new Exception(config('msg.redis.1201'), 1201);
    }

    /**
     * 验证redis重复性
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public static function getVerityRepeatRedis($id,$instanceName,$instanceId)
    {
        $verity = RedisModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where(function ($query) use ($instanceName,$instanceId) {
            return $query->where('instance_name', $instanceName)->orWhere('instance_id',$instanceId);
        })->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 编辑redis
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public function getRedisEdit($postData)
    {
        $verity = self::getVerityRepeatRedis($postData['id'],$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.redis.1202'), 1202);
        $redis = RedisModel::find($postData['id']);
        if(!$redis) throw new Exception(config('msg.redis.1203'),1203);
        $redis->instance_name = $postData['instanceName'] ?? '';
        $redis->instance_id = $postData['instanceId'] ?? '';
        $redis->capacity = $postData['capacity'] ?? '';
        $redis->quota = $postData['quota'] ?? '';
        $redis->edition = $postData['edition'] ?? '';
        $redis->norms = $postData['norms'] ?? '';
        $redis->pay_type = $postData['payType'] ?? 0;
        $redis->network_type = $postData['networkType'] ?? 0;
        $redis->region = $postData['region'] ?? '';
        $redis->expire_time = $postData['expireTime'] ?? '';
        $redis->cloud_id = $postData['cloudId'];
        $redis->project_id = $postData['projectId'];
        $redis->created_at = $postData['createdAt'];
        if($redis->save()) return $redis->id;
        throw new Exception(config('msg.redis.1204'),1204);
    }
}