<?php
namespace App\Services\Slb;

use App\Models\SlbModel;
use App\Services\Slb\ISlbService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Cache;

class SlbService implements ISlbService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * slb列表
     * @return array
     * @date 2020/10/18
     * @author live
     */
    public function getSlbList($postData)
    {
        $array = ['totalNum'=>0,'totalPage'=>0,'data'=>[]];

        $instanceName = $postData['instanceName']??'';
        $cloudId = $postData['cloudId']??0;
        $projectId = $postData['projectId']??0;
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $slbs = SlbModel::with(['getRelationProject:id,cn_name,en_name','getCloudProject:id,cloud_name,account_name'])->when($instanceName != '', function ($query) use ($instanceName) {
            return $query->where('instance_name', 'like',$instanceName.'%');
        })->when($cloudId > 0, function ($query) use ($cloudId) {
            return $query->where('cloud_id',$cloudId);
        })->when($projectId > 0, function ($query) use ($projectId) {
            return $query->where('project_id',$projectId);
        })->select('id','instance_name','instance_id','outer_ip','backend_ip_list','cloud_id','project_id','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $slbs->total();
        $array['totalPage'] = $slbs->lastPage();
        foreach($slbs as $slb){
            $tem['id'] = $slb->id;
            $tem['instanceName'] = $slb->instance_name;
            $tem['instanceId'] = $slb->instance_id;
            $tem['outerIp'] = $slb->outer_ip;
            $tem['backendIpList'] = $slb->backend_ip_list;
            $tem['projectId'] = $slb->project_id;
            $tem['projecCnName'] = $slb->getRelationProject->cn_name ?? '';
            $tem['projecEnName'] = $slb->getRelationProject->en_name ?? '';
            $tem['cloudId'] = $slb->cloud_id;
            $tem['cloudName'] = $slb->getCloudProject->cloud_name ?? '';
            $tem['cloudAccount'] = $slb->getCloudProject->account_name ?? '';
            $tem['created_at'] = Carbon::parse($slb->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($slbs,$slb,$tem);
        return $array;
    }

    /**
     * 删除slb
     * @return bool
     * @date 2020/10/18
     * @author live
     */
    public function getSlbDel($postData)
    {
        $slb = SlbModel::where('id',$postData['id'])->where('instance_id',$postData['instanceId'])->first();
        if(!$slb) throw new Exception(config('msg.slb.9003'),9003);
        if($slb->delete()) return true;
        throw new Exception(config('msg.slb.9005'),9005);
    }

    /**
     * 新增slb
     * @return array
     * @date 2020/11/23
     * @author live
     */
    public function getSlbAdd($postData)
    {
        $verity = self::getVerityRepeatSlb(0,$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.slb.9002'), 9002);
        $row = new SlbModel();
        $row->instance_name = $postData['instanceName'] ?? '';
        $row->instance_id = $postData['instanceId'] ?? '';
        $row->outer_ip = $postData['outerIp'] ?? '';
        $row->backend_ip_list = $postData['backendIpList'] ?? '';
        $row->cloud_id = $postData['cloudId'] ?? 0;
        $row->project_id = $postData['projectId'] ?? 0;
        $row->created_at = $postData['createdAt'] ?? $this->time;
        if ($row->save()) return $row->id;
        throw new Exception(config('msg.slb.9001'), 9001);
    }

    /**
     * 验证slb重复性
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public static function getVerityRepeatSlb($id,$instanceName,$instanceId)
    {
        $verity = SlbModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where(function ($query) use ($instanceName,$instanceId) {
            return $query->where('instance_name', $instanceName)->orWhere('instance_id',$instanceId);
        })->select('id')->first();
        if($verity) return false;
        return true;
    }

    /**
     * 编辑slb
     * @return bool
     * @date 2020/10/23
     * @author live
     */
    public function getSlbEdit($postData)
    {
        $verity = self::getVerityRepeatSlb($postData['id'],$postData['instanceName'],$postData['instanceId']);
        if(!$verity) throw new Exception(config('msg.slb.9002'), 9002);
        $slb = SlbModel::find($postData['id']);
        if(!$slb) throw new Exception(config('msg.slb.9003'),9003);
        $slb->instance_name = $postData['instanceName'];
        $slb->instance_id = $postData['instanceId'];
        $slb->outer_ip = $postData['outerIp'];
        $slb->backend_ip_list = $postData['backendIpList'];
        $slb->cloud_id = $postData['cloudId'];
        $slb->project_id = $postData['projectId'];
        $slb->created_at = $postData['createdAt'];
        if($slb->save()) return $slb->id;
        throw new Exception(config('msg.slb.9004'),9004);
    }
}