<?php
namespace App\Services\User;

use App\Services\User\IUserService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use App\Models\AdminModel;
use Illuminate\Support\Facades\Cache;
use Tymon\JWTAuth\Facades\JWTAuth;

class UserService implements IUserService{
    private $time;
    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增用户
     * @return int
     * @date 2020/10/17
     * @author live
     */
    public function getUserAdd($postData)
    {
        $verity = self::getVerityRepeatUser(0,$postData['name'],$postData['email']);
        if($verity){
            $row = new AdminModel();
            $row->name = $postData['name'] ?? '';
            $row->real_name = $postData['realName'] ?? '';
            $row->email = $postData['email'] ?? '';
            $row->phone = $postData['phone'] ?? '';
            $row->password = bcrypt($postData['pwd']);
            $row->option_id = $postData['user']['id'];
            if( $row->save()) return $row->id;
            throw new Exception(config('msg.user.2002'),2002);
        }
        throw new Exception(config('msg.user.2001'),2001);
    }

    /**
     * 检验用户重复性
     * @return bool
     * @date 2020/10/17
     * @author live
     */
    public static function getVerityRepeatUser($id = 0,$name,$email){
        $verity = AdminModel::when($id > 0, function ($query) use ($id) {
            return $query->where('id', '!=',$id);
        })->where(function ($query) use ($name,$email) {
            return $query->where('name', $name)->orWhere('email',$email);
        })->select('id')->first();

        if($verity) return false;
        return true;

    }

    /**
     * 用户列表
     * @return araay
     * @date 2020/10/17
     * @author live
     */
    public function getUserList($postData)
    {
        $key = $postData['key']??'';
        $pagePerNum = $postData['pageSize']??20;
        $currentPage = $postData['page']??1;

        $users = AdminModel::with(['optionUser:id,name'])->when($key != '', function ($query) use ($key) {
            return $query->where('name', 'like',$key.'%')->orWhere('real_name', 'like',$key.'%')->orWhere('email', 'like',$key.'%')->orWhere('phone', 'like',$key.'%');
        })->select('id','name','real_name','email','phone','option_id','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);

        $array['totalNum'] = $users->total();
        $array['totalPage'] = $users->lastPage();
        foreach($users as $user){
            $tem['id'] = $user->id;
            $tem['name'] = $user->name;
            $tem['realName'] = $user->real_name;
            $tem['email'] = $user->email;
            $tem['phone'] = $user->phone;
            $tem['optionName'] = $user->optionUser->name ?? '';
            $tem['created_at'] = Carbon::parse($user->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($users,$user,$user);
        return $array;
    }

    /**
     * 用户登录
     * @return araay
     * @date 2020/10/17
     * @author live
     */
    public function getLogin($postData){
        $array['token'] = '';
        $credentials = ['name'=>$postData['name'], 'password'=>$postData['pwd']];
        if (! $token = JWTAuth::attempt($credentials)){
            throw new Exception(config('msg.user.2003'),2003);
        }
        $user = AdminModel::where('name',$postData['name'])->select('id','token')->first();
        $userToken = MD5($token);
        $user->token = $userToken;
        $user->save();
        Cache::put('login_'.$userToken,1,60);
        $array['token'] = $token;
        unset($user,$userToken);
        return $array;
    }

    /**
     * 退出登录
     * @return araay
     * @date 2020/10/17
     * @author live
     */
    public function getLoginOut($token)
    {
        $userToken = MD5($token);
        if(Cache::has('login_'.$userToken)) Cache::forget('login_'.$userToken);
        $user = AdminModel::where('token',$userToken)->select('id','token')->first();
        $user->token = '';
        $user->save();
        return true;
    }

    /**
     * 编辑用户
     * @return araay
     * @date 2020/10/17
     * @author live
     */
    public function getUserEdit($postData)
    {
        $verity = self::getVerityRepeatUser($postData['id'],'',$postData['email']);
        if($verity){
            $user = AdminModel::find($postData['id']);
            if(!$user) throw new Exception(config('msg.user.2004'),2004);
            $user->real_name = $postData['realName'];
            $user->email = $postData['email'];
            $user->phone = $postData['phone'];
            if($user->save()) return $user->id;
            throw new Exception(config('msg.user.2005'),2005);
        }
        throw new Exception(config('msg.user.2001'),2001);
    }

    /**
     * 删除用户
     * @return araay
     * @date 2020/10/17
     * @author live
     */
    public function getUserDel($postData)
    {
        $user = AdminModel::where('id',$postData['id'])->where('name',$postData['name'])->first();
        if(!$user) throw new Exception(config('msg.user.2004'),2004);
        if($user->delete()) return true;
        throw new Exception(config('msg.user.2006'),2006);
    }

    /**
     * 修改用户登录密码
     * @return araay
     * @date 2020/10/17
     * @author live
     */
    public function getResetUserPwd($postData)
    {
        $user = AdminModel::where('id',$postData['id'])->where('name',$postData['name'])->first();
        if(!$user) throw new Exception(config('msg.user.2004'),2004);
        $userToken = $user->token;
        $user->password = bcrypt($postData['pwd']);
        $user->token = '';
        if($user->save()){
            if(Cache::has('login_'.$userToken)) Cache::forget('login_'.$userToken);
            return true;
        }
        throw new Exception(config('msg.user.2007'),2007);
    }
}